Label

Struct Label 

#[repr(transparent)]
pub struct Label<Tag: WithLt<L>, L: LifetimeList = L0>(pub <Tag as WithLt<L>>::Reified);
Wrapper that reports as being tagged by a specific tag.

Not all types implement Tagged. This wrapper can be used in those cases to have a type that with reify to itself after using it’s tag.

Tuple Fields

0: <Tag as WithLt<L>>::Reified

Implementations

Source

impl<L: LifetimeList, Tag: WithLt<L>> Label<Tag, L>
where Tag::Reified: Sized,

pub const fn new(value: <Tag as WithLt<L>>::Reified) -> Self

pub const fn into_inner(self) -> <Tag as WithLt<L>>::Reified

Available on crate feature unsafe only.
Source

impl<L: LifetimeList, Tag: WithLt<L>> Label<Tag, L>

pub const fn from_ref(value: &<Tag as WithLt<L>>::Reified) -> &Self

Available on crate feature unsafe only.
pub const fn from_mut(value: &mut <Tag as WithLt<L>>::Reified) -> &mut Self

Available on crate feature unsafe only.
pub const fn to_ref(&self) -> &<Tag as WithLt<L>>::Reified

Available on crate feature unsafe only.
pub const fn to_mut(&mut self) -> &mut <Tag as WithLt<L>>::Reified

Available on crate feature unsafe only.